@@ -31,6 +31,8 @@ from gettext import translation
 
 appdir="/usr/share/applications/hildon"
 
+apps={}
+
 def readOneFn(fn):
     global appdir
 
@@ -105,7 +107,7 @@ def readOne(name):
     return(ret)
 
 def scan():
-    global appdir
+    global appdir, apps
 
     files=os.listdir(appdir)
 
@@ -127,8 +129,15 @@ def scan():
 	t=f[:-8]
 	ret[t]=dt
 
+    apps=ret
+
     return(ret)
 
+def getLastScan():
+    global apps
+
+    return(apps)
+
 if __name__=="__main__":
     #locale.setlocale(locale.LC_ALL, '')
     print scan()
